#!/bin/sh
#
# Package: auto-pilot
# Charles P. Wright <cwright@cs.sunysb.edu>
# Erez Zadok <ezk@cs.sunysb.edu>
# Copyright (c) 2001-2006 Stony Brook University

# Use common settings

source commonsettings || exit $?

if [ -z "$TESTROOT" ] ; then
	echo "You must specify the TESTDIR as an environment variable."
	exit 1
fi

personality=$1
EVENTRATE=$2

CONFIG=/tmp/fsbench.cfg
TESTDIR=$TESTROOT/fsbench_dir
set_default FBLOGDIR $LOGDIR/stats.$APEPOCH
STDOUT="/tmp/logs/stdout-$APEPOCH"
echo "Running the test on $TESTDIR"

# Change the ulimit file descriptor number
ulimit -n 50000

# If not to use default. 
if [ $USE_DEFAULT = "0" ] ; then
	# Per workload environment variables
	if [ $personality == "oltp" ] ; then
		set_default FILESIZE 500m
		set_default IOSIZE 2k
		set_default RUNTIME 600
	fi

	if [ $personality == "fileserver" ] ; then
		set_default NFILES 50000
		set_default DIRWIDTH 20
		set_default FILESIZE 256k 
		set_default NTHREADS 100
		set_default DIRECTIO 0
		set_default RUNTIME  600
	fi

	if [ $personality == "webserver" ] ; then
		set_default NFILES 20000
		set_default DIRWIDTH 20
		set_default FILESIZE 32k 
		set_default NTHREADS 100
		set_default IOSIZE 1m
		set_default RUNTIME  600
	fi

	if [ $personality == "varmail" ] ; then
		set_default NFILES 50000
		set_default FILESIZE 16k 
		set_default DIRWIDTH 1000000 
		set_default NTHREADS 100
		set_default MEANIOSIZE 16k
		set_default READIOSIZE 1m 
		set_default RUNTIME  600
	fi
	
	# Micro Benchmarks 
	if [ $personality == "filemicro_rread" ] ; then
		echo "File Micro RRead ..."
		set_default IOSIZE 2k
		set_default NTHREADS 1
		set_default BYTES 1g
		set_default FILESIZE 4g 
		set_default RUNTIME  4000
	fi

	if [ $personality == "filemicro_rwrite" ] ; then
		echo "File Micro RWrite ..."
		set_default IOSIZE 2k
		set_default NTHREADS 1
		set_default BYTES 1g
		set_default FILESIZE 4g 
		set_default RUNTIME  4000
	fi

if [ $personality == "oltp" ] ; then

TEST_RUNTIME=$RUNTIME
:q
cat <<PM_CONFIG > $CONFIG 
load $personality
set \$dir=$TESTDIR
set \$filesize=$FILESIZE
set \$iosize=$IOSIZE
run $RUNTIME
stats dump "$FBLOGDIR"
quit
PM_CONFIG

else

TEST_RUNTIME=$RUNTIME
cat <<PM_CONFIG > $CONFIG 
load $personality
set \$dir=$TESTDIR
set \$nfiles=$NFILES
set \$nthreads=$NTHREADS
set \$filesize=$FILESIZE
set \$iosize=$IOSIZE
set \$meandirwidth=$DIRWIDTH
set \$dirwidth=$DIRWIDTH
set \$directio=$DIRECTIO
set \$nshadows=$NSHADOWS
set \$ndbwriters=$NDBWRITERS
set \$readiosize=$READIOSIZE
run $RUNTIME
stats dump "$FBLOGDIR"
quit
PM_CONFIG

fi

else
	echo "Using default options"
TEST_RUNTIME=$RUNTIME

cat <<PM_CONFIG > $CONFIG 
load $personality
set \$dir=$TESTDIR
run $RUNTIME
stats dump "$FBLOGDIR"
quit
PM_CONFIG

fi

ap_hook pmextra $CONFIG
cat "$CONFIG"
ap_measure go_filebench<"$CONFIG" 2>&1 | tee $STDOUT

echo "Deleting the config file"
rm -f "$CONFIG"

echo "FileBench Over"
